@@ -472,6 +472,9 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                     if (os == 'android' || os == 'ios'){
                         let orig_action = action;
                         action = () => {
+                            if (button.isFocusable()) {
+                                button.focus();
+                            }
                             setTimeout(orig_action.bind(this),1);
                         }
                     }        
